
/* Generated data (by glib-mkenums) */

#include <gobject/genums.h>
#include "libgnomeui.h"

#include "gnometypebuiltins.h"



/* enumerations from "gnome-client.h" */
static const GEnumValue _gnome_interact_style_values[] = {
  { GNOME_INTERACT_NONE, "GNOME_INTERACT_NONE", "none" },
  { GNOME_INTERACT_ERRORS, "GNOME_INTERACT_ERRORS", "errors" },
  { GNOME_INTERACT_ANY, "GNOME_INTERACT_ANY", "any" },
  { 0, NULL, NULL }
};

GType
gnome_interact_style_get_type (void)
{
  static GType type = 0;

  if (!type)
    type = g_enum_register_static ("GnomeInteractStyle", _gnome_interact_style_values);

  return type;
}


static const GEnumValue _gnome_dialog_type_values[] = {
  { GNOME_DIALOG_ERROR, "GNOME_DIALOG_ERROR", "error" },
  { GNOME_DIALOG_NORMAL, "GNOME_DIALOG_NORMAL", "normal" },
  { 0, NULL, NULL }
};

GType
gnome_dialog_type_get_type (void)
{
  static GType type = 0;

  if (!type)
    type = g_enum_register_static ("GnomeDialogType", _gnome_dialog_type_values);

  return type;
}


static const GEnumValue _gnome_save_style_values[] = {
  { GNOME_SAVE_GLOBAL, "GNOME_SAVE_GLOBAL", "global" },
  { GNOME_SAVE_LOCAL, "GNOME_SAVE_LOCAL", "local" },
  { GNOME_SAVE_BOTH, "GNOME_SAVE_BOTH", "both" },
  { 0, NULL, NULL }
};

GType
gnome_save_style_get_type (void)
{
  static GType type = 0;

  if (!type)
    type = g_enum_register_static ("GnomeSaveStyle", _gnome_save_style_values);

  return type;
}


static const GEnumValue _gnome_restart_style_values[] = {
  { GNOME_RESTART_IF_RUNNING, "GNOME_RESTART_IF_RUNNING", "if-running" },
  { GNOME_RESTART_ANYWAY, "GNOME_RESTART_ANYWAY", "anyway" },
  { GNOME_RESTART_IMMEDIATELY, "GNOME_RESTART_IMMEDIATELY", "immediately" },
  { GNOME_RESTART_NEVER, "GNOME_RESTART_NEVER", "never" },
  { 0, NULL, NULL }
};

GType
gnome_restart_style_get_type (void)
{
  static GType type = 0;

  if (!type)
    type = g_enum_register_static ("GnomeRestartStyle", _gnome_restart_style_values);

  return type;
}


static const GEnumValue _gnome_client_state_values[] = {
  { GNOME_CLIENT_IDLE, "GNOME_CLIENT_IDLE", "idle" },
  { GNOME_CLIENT_SAVING_PHASE_1, "GNOME_CLIENT_SAVING_PHASE_1", "saving-phase-1" },
  { GNOME_CLIENT_WAITING_FOR_PHASE_2, "GNOME_CLIENT_WAITING_FOR_PHASE_2", "waiting-for-phase-2" },
  { GNOME_CLIENT_SAVING_PHASE_2, "GNOME_CLIENT_SAVING_PHASE_2", "saving-phase-2" },
  { GNOME_CLIENT_FROZEN, "GNOME_CLIENT_FROZEN", "frozen" },
  { GNOME_CLIENT_DISCONNECTED, "GNOME_CLIENT_DISCONNECTED", "disconnected" },
  { GNOME_CLIENT_REGISTERING, "GNOME_CLIENT_REGISTERING", "registering" },
  { 0, NULL, NULL }
};

GType
gnome_client_state_get_type (void)
{
  static GType type = 0;

  if (!type)
    type = g_enum_register_static ("GnomeClientState", _gnome_client_state_values);

  return type;
}


static const GFlagsValue _gnome_client_flags_values[] = {
  { GNOME_CLIENT_IS_CONNECTED, "GNOME_CLIENT_IS_CONNECTED", "is-connected" },
  { GNOME_CLIENT_RESTARTED, "GNOME_CLIENT_RESTARTED", "restarted" },
  { GNOME_CLIENT_RESTORED, "GNOME_CLIENT_RESTORED", "restored" },
  { 0, NULL, NULL }
};

GType
gnome_client_flags_get_type (void)
{
  static GType type = 0;

  if (!type)
    type = g_flags_register_static ("GnomeClientFlags", _gnome_client_flags_values);

  return type;
}



/* enumerations from "gnome-dateedit.h" */
static const GFlagsValue _gnome_date_edit_flags_values[] = {
  { GNOME_DATE_EDIT_SHOW_TIME, "GNOME_DATE_EDIT_SHOW_TIME", "show-time" },
  { GNOME_DATE_EDIT_24_HR, "GNOME_DATE_EDIT_24_HR", "24-hr" },
  { GNOME_DATE_EDIT_WEEK_STARTS_ON_MONDAY, "GNOME_DATE_EDIT_WEEK_STARTS_ON_MONDAY", "week-starts-on-monday" },
  { 0, NULL, NULL }
};

GType
gnome_date_edit_flags_get_type (void)
{
  static GType type = 0;

  if (!type)
    type = g_flags_register_static ("GnomeDateEditFlags", _gnome_date_edit_flags_values);

  return type;
}



/* enumerations from "gnome-druid-page-edge.h" */
static const GEnumValue _gnome_edge_position_values[] = {
  { GNOME_EDGE_START, "GNOME_EDGE_START", "start" },
  { GNOME_EDGE_FINISH, "GNOME_EDGE_FINISH", "finish" },
  { GNOME_EDGE_OTHER, "GNOME_EDGE_OTHER", "other" },
  { GNOME_EDGE_LAST, "GNOME_EDGE_LAST", "last" },
  { 0, NULL, NULL }
};

GType
gnome_edge_position_get_type (void)
{
  static GType type = 0;

  if (!type)
    type = g_enum_register_static ("GnomeEdgePosition", _gnome_edge_position_values);

  return type;
}



/* enumerations from "gnome-icon-list.h" */
static const GEnumValue _gnome_icon_list_mode_values[] = {
  { GNOME_ICON_LIST_ICONS, "GNOME_ICON_LIST_ICONS", "icons" },
  { GNOME_ICON_LIST_TEXT_BELOW, "GNOME_ICON_LIST_TEXT_BELOW", "text-below" },
  { GNOME_ICON_LIST_TEXT_RIGHT, "GNOME_ICON_LIST_TEXT_RIGHT", "text-right" },
  { 0, NULL, NULL }
};

GType
gnome_icon_list_mode_get_type (void)
{
  static GType type = 0;

  if (!type)
    type = g_enum_register_static ("GnomeIconListMode", _gnome_icon_list_mode_values);

  return type;
}



/* enumerations from "gnome-types.h" */
static const GEnumValue _gnome_preferences_type_values[] = {
  { GNOME_PREFERENCES_NEVER, "GNOME_PREFERENCES_NEVER", "never" },
  { GNOME_PREFERENCES_USER, "GNOME_PREFERENCES_USER", "user" },
  { GNOME_PREFERENCES_ALWAYS, "GNOME_PREFERENCES_ALWAYS", "always" },
  { 0, NULL, NULL }
};

GType
gnome_preferences_type_get_type (void)
{
  static GType type = 0;

  if (!type)
    type = g_enum_register_static ("GnomePreferencesType", _gnome_preferences_type_values);

  return type;
}



/* enumerations from "gnome-winhints.h" */
static const GEnumValue _gnome_win_layer_values[] = {
  { WIN_LAYER_DESKTOP, "WIN_LAYER_DESKTOP", "desktop" },
  { WIN_LAYER_BELOW, "WIN_LAYER_BELOW", "below" },
  { WIN_LAYER_NORMAL, "WIN_LAYER_NORMAL", "normal" },
  { WIN_LAYER_ONTOP, "WIN_LAYER_ONTOP", "ontop" },
  { WIN_LAYER_DOCK, "WIN_LAYER_DOCK", "dock" },
  { WIN_LAYER_ABOVE_DOCK, "WIN_LAYER_ABOVE_DOCK", "above-dock" },
  { 0, NULL, NULL }
};

GType
gnome_win_layer_get_type (void)
{
  static GType type = 0;

  if (!type)
    type = g_enum_register_static ("GnomeWinLayer", _gnome_win_layer_values);

  return type;
}


static const GFlagsValue _gnome_win_state_values[] = {
  { WIN_STATE_STICKY, "WIN_STATE_STICKY", "sticky" },
  { WIN_STATE_MINIMIZED, "WIN_STATE_MINIMIZED", "minimized" },
  { WIN_STATE_MAXIMIZED_VERT, "WIN_STATE_MAXIMIZED_VERT", "maximized-vert" },
  { WIN_STATE_MAXIMIZED_HORIZ, "WIN_STATE_MAXIMIZED_HORIZ", "maximized-horiz" },
  { WIN_STATE_HIDDEN, "WIN_STATE_HIDDEN", "hidden" },
  { WIN_STATE_SHADED, "WIN_STATE_SHADED", "shaded" },
  { WIN_STATE_HID_WORKSPACE, "WIN_STATE_HID_WORKSPACE", "hid-workspace" },
  { WIN_STATE_HID_TRANSIENT, "WIN_STATE_HID_TRANSIENT", "hid-transient" },
  { WIN_STATE_FIXED_POSITION, "WIN_STATE_FIXED_POSITION", "fixed-position" },
  { WIN_STATE_ARRANGE_IGNORE, "WIN_STATE_ARRANGE_IGNORE", "arrange-ignore" },
  { 0, NULL, NULL }
};

GType
gnome_win_state_get_type (void)
{
  static GType type = 0;

  if (!type)
    type = g_flags_register_static ("GnomeWinState", _gnome_win_state_values);

  return type;
}


static const GFlagsValue _gnome_win_hints_values[] = {
  { WIN_HINTS_SKIP_FOCUS, "WIN_HINTS_SKIP_FOCUS", "skip-focus" },
  { WIN_HINTS_SKIP_WINLIST, "WIN_HINTS_SKIP_WINLIST", "skip-winlist" },
  { WIN_HINTS_SKIP_TASKBAR, "WIN_HINTS_SKIP_TASKBAR", "skip-taskbar" },
  { WIN_HINTS_GROUP_TRANSIENT, "WIN_HINTS_GROUP_TRANSIENT", "group-transient" },
  { WIN_HINTS_FOCUS_ON_CLICK, "WIN_HINTS_FOCUS_ON_CLICK", "focus-on-click" },
  { WIN_HINTS_DO_NOT_COVER, "WIN_HINTS_DO_NOT_COVER", "do-not-cover" },
  { 0, NULL, NULL }
};

GType
gnome_win_hints_get_type (void)
{
  static GType type = 0;

  if (!type)
    type = g_flags_register_static ("GnomeWinHints", _gnome_win_hints_values);

  return type;
}


static const GEnumValue _gnome_win_app_state_values[] = {
  { WIN_APP_STATE_NONE, "WIN_APP_STATE_NONE", "none" },
  { WIN_APP_STATE_ACTIVE1, "WIN_APP_STATE_ACTIVE1", "active1" },
  { WIN_APP_STATE_ACTIVE2, "WIN_APP_STATE_ACTIVE2", "active2" },
  { WIN_APP_STATE_ERROR1, "WIN_APP_STATE_ERROR1", "error1" },
  { WIN_APP_STATE_ERROR2, "WIN_APP_STATE_ERROR2", "error2" },
  { WIN_APP_STATE_FATAL_ERROR1, "WIN_APP_STATE_FATAL_ERROR1", "fatal-error1" },
  { WIN_APP_STATE_FATAL_ERROR2, "WIN_APP_STATE_FATAL_ERROR2", "fatal-error2" },
  { WIN_APP_STATE_IDLE1, "WIN_APP_STATE_IDLE1", "idle1" },
  { WIN_APP_STATE_IDLE2, "WIN_APP_STATE_IDLE2", "idle2" },
  { WIN_APP_STATE_WAITING1, "WIN_APP_STATE_WAITING1", "waiting1" },
  { WIN_APP_STATE_WAITING2, "WIN_APP_STATE_WAITING2", "waiting2" },
  { WIN_APP_STATE_WORKING1, "WIN_APP_STATE_WORKING1", "working1" },
  { WIN_APP_STATE_WORKING2, "WIN_APP_STATE_WORKING2", "working2" },
  { WIN_APP_STATE_NEED_USER_INPUT1, "WIN_APP_STATE_NEED_USER_INPUT1", "need-user-input1" },
  { WIN_APP_STATE_NEED_USER_INPUT2, "WIN_APP_STATE_NEED_USER_INPUT2", "need-user-input2" },
  { WIN_APP_STATE_STRUGGLING1, "WIN_APP_STATE_STRUGGLING1", "struggling1" },
  { WIN_APP_STATE_STRUGGLING2, "WIN_APP_STATE_STRUGGLING2", "struggling2" },
  { WIN_APP_STATE_DISK_TRAFFIC1, "WIN_APP_STATE_DISK_TRAFFIC1", "disk-traffic1" },
  { WIN_APP_STATE_DISK_TRAFFIC2, "WIN_APP_STATE_DISK_TRAFFIC2", "disk-traffic2" },
  { WIN_APP_STATE_NETWORK_TRAFFIC1, "WIN_APP_STATE_NETWORK_TRAFFIC1", "network-traffic1" },
  { WIN_APP_STATE_NETWORK_TRAFFIC2, "WIN_APP_STATE_NETWORK_TRAFFIC2", "network-traffic2" },
  { WIN_APP_STATE_OVERLOADED1, "WIN_APP_STATE_OVERLOADED1", "overloaded1" },
  { WIN_APP_STATE_OVERLOADED2, "WIN_APP_STATE_OVERLOADED2", "overloaded2" },
  { WIN_APP_STATE_PERCENT000_1, "WIN_APP_STATE_PERCENT000_1", "percent000-1" },
  { WIN_APP_STATE_PERCENT000_2, "WIN_APP_STATE_PERCENT000_2", "percent000-2" },
  { WIN_APP_STATE_PERCENT010_1, "WIN_APP_STATE_PERCENT010_1", "percent010-1" },
  { WIN_APP_STATE_PERCENT010_2, "WIN_APP_STATE_PERCENT010_2", "percent010-2" },
  { WIN_APP_STATE_PERCENT020_1, "WIN_APP_STATE_PERCENT020_1", "percent020-1" },
  { WIN_APP_STATE_PERCENT020_2, "WIN_APP_STATE_PERCENT020_2", "percent020-2" },
  { WIN_APP_STATE_PERCENT030_1, "WIN_APP_STATE_PERCENT030_1", "percent030-1" },
  { WIN_APP_STATE_PERCENT030_2, "WIN_APP_STATE_PERCENT030_2", "percent030-2" },
  { WIN_APP_STATE_PERCENT040_1, "WIN_APP_STATE_PERCENT040_1", "percent040-1" },
  { WIN_APP_STATE_PERCENT040_2, "WIN_APP_STATE_PERCENT040_2", "percent040-2" },
  { WIN_APP_STATE_PERCENT050_1, "WIN_APP_STATE_PERCENT050_1", "percent050-1" },
  { WIN_APP_STATE_PERCENT050_2, "WIN_APP_STATE_PERCENT050_2", "percent050-2" },
  { WIN_APP_STATE_PERCENT060_1, "WIN_APP_STATE_PERCENT060_1", "percent060-1" },
  { WIN_APP_STATE_PERCENT060_2, "WIN_APP_STATE_PERCENT060_2", "percent060-2" },
  { WIN_APP_STATE_PERCENT070_1, "WIN_APP_STATE_PERCENT070_1", "percent070-1" },
  { WIN_APP_STATE_PERCENT070_2, "WIN_APP_STATE_PERCENT070_2", "percent070-2" },
  { WIN_APP_STATE_PERCENT080_1, "WIN_APP_STATE_PERCENT080_1", "percent080-1" },
  { WIN_APP_STATE_PERCENT080_2, "WIN_APP_STATE_PERCENT080_2", "percent080-2" },
  { WIN_APP_STATE_PERCENT090_1, "WIN_APP_STATE_PERCENT090_1", "percent090-1" },
  { WIN_APP_STATE_PERCENT090_2, "WIN_APP_STATE_PERCENT090_2", "percent090-2" },
  { WIN_APP_STATE_PERCENT100_1, "WIN_APP_STATE_PERCENT100_1", "percent100-1" },
  { WIN_APP_STATE_PERCENT100_2, "WIN_APP_STATE_PERCENT100_2", "percent100-2" },
  { 0, NULL, NULL }
};

GType
gnome_win_app_state_get_type (void)
{
  static GType type = 0;

  if (!type)
    type = g_enum_register_static ("GnomeWinAppState", _gnome_win_app_state_values);

  return type;
}



/* Generated data ends here */

